Crate barter_instrument

Crate barter_instrument 

Barter-Instrument

Barter-Instrument contains core Exchange, Instrument and Asset data structures and associated utilities.

Examples

For a comprehensive collection of examples, see the Barter core Engine /examples directory.

Modules

asset
Asset related data structures.
exchange
Defines a global ExchangeId enum covering all exchanges.
index
Indexed collection of exchanges, assets, and instruments. Provides a builder utility for indexing non-indexed collections.
instrument
Instrument related data structures.
test_utils

Structs

Keyed
A keyed value.
Underlying
Instrument Underlying containing a base and quote asset.

Enums

Side
Side of a trade or position - Buy or Sell.